==> taler-wallet-v0.9.4a.tar.gz: taler-wallet-v0.9.4a/packages/merchant-backoffice-ui/src/paths/instance/templates/list/ListPage.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2023 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { h, VNode } from "preact";
import { MerchantBackend } from "../../../../declaration.js";
import { useTranslationContext } from "@gnu-taler/web-util/browser";
import { CardTable } from "./Table.js";

export interface Props {
  templates: MerchantBackend.Template.TemplateEntry[];
  onLoadMoreBefore?: () => void;
  onLoadMoreAfter?: () => void;
  onCreate: () => void;
  onDelete: (e: MerchantBackend.Template.TemplateEntry) => void;
  onSelect: (e: MerchantBackend.Template.TemplateEntry) => void;
  onNewOrder: (e: MerchantBackend.Template.TemplateEntry) => void;
  onQR: (e: MerchantBackend.Template.TemplateEntry) => void;
}

export function ListPage({
  templates,
  onCreate,
  onDelete,
  onSelect,
  onNewOrder,
  onQR,
  onLoadMoreBefore,
  onLoadMoreAfter,
}: Props): VNode {
  const form = { payto_uri: "" };

  const { i18n } = useTranslationContext();
  return (
      <CardTable
        templates={templates.map((o) => ({
          ...o,
          id: String(o.template_id),
        }))}
        onQR={onQR}
        onCreate={onCreate}
        onDelete={onDelete}
        onSelect={onSelect}
        onNewOrder={onNewOrder}
        onLoadMoreBefore={onLoadMoreBefore}
        hasMoreBefore={!onLoadMoreBefore}
        onLoadMoreAfter={onLoadMoreAfter}
        hasMoreAfter={!onLoadMoreAfter}
      />
  );
}

==> taler-wallet-v0.10.6.tar.gz: taler-wallet-v0.10.6/packages/merchant-backoffice-ui/src/paths/instance/templates/list/ListPage.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { TalerMerchantApi } from "@gnu-taler/taler-util";
import { h, VNode } from "preact";
import { CardTable } from "./Table.js";

export interface Props {
  templates: TalerMerchantApi.TemplateEntry[];
  onLoadMoreBefore?: () => void;
  onLoadMoreAfter?: () => void;
  onCreate: () => void;
  onDelete: (e: TalerMerchantApi.TemplateEntry) => void;
  onSelect: (e: TalerMerchantApi.TemplateEntry) => void;
  onNewOrder: (e: TalerMerchantApi.TemplateEntry) => void;
  onQR: (e: TalerMerchantApi.TemplateEntry) => void;
}

export function ListPage({
  templates,
  onCreate,
  onDelete,
  onSelect,
  onNewOrder,
  onQR,
  onLoadMoreBefore,
  onLoadMoreAfter,
}: Props): VNode {

  return (
      <CardTable
        templates={templates.map((o) => ({
          ...o,
          id: String(o.template_id),
        }))}
        onQR={onQR}
        onCreate={onCreate}
        onDelete={onDelete}
        onSelect={onSelect}
        onNewOrder={onNewOrder}
        onLoadMoreBefore={onLoadMoreBefore}
        onLoadMoreAfter={onLoadMoreAfter}
      />
  );
}
